@@ -111,6 +111,8 @@ class _CIMComparisonMixin(object):  # pylint: disable=too-few-public-methods
     Therefore, implementing the rich comparison operators works in both.
     """
 
+    __slots__ = []
+
     def __eq__(self, other):
         """
         Equality test for two CIM objects.
@@ -140,15 +142,19 @@ class _CIMComparisonMixin(object):  # pylint: disable=too-few-public-methods
             format(op, type(self), type(other)))
 
     def __lt__(self, other):
+        ""  # Avoids docstring to be inherited
         self.__raise_ordering_not_supported(other, '<')
 
     def __gt__(self, other):
+        ""  # Avoids docstring to be inherited
         self.__raise_ordering_not_supported(other, '>')
 
     def __ge__(self, other):
+        ""  # Avoids docstring to be inherited
         self.__raise_ordering_not_supported(other, '>=')
 
     def __le__(self, other):
+        ""  # Avoids docstring to be inherited
         self.__raise_ordering_not_supported(other, '<=')
 
     def __hash__(self):
@@ -166,7 +172,71 @@ class _CIMComparisonMixin(object):  # pylint: disable=too-few-public-methods
         raise NotImplementedError
 
 
-class MinutesFromUTC(tzinfo):
+class SlottedPickleMixin(object):
+    """
+    On Python 2, the built-in 'pickle' module uses pickle protocol 0 by default.
+    Using protocol 0 causes pickle to raise TypeError for objects with slots
+    that do not define methods __getstate__() and __setstate__().
+
+    In Python 3.0, the default pickle protocol changed to protocol 3 and in
+    Python 3.8 to protocol 4, both of which support objects with slots by
+    default, without requiring that they define methods __getstate__() and
+    __setstate__().
+
+    That led to the idea to provide these methods only when running on
+    Python 2. However, it turns out that objects pickled before this change
+    (using the built-in methods) save all attributes in one shot by saving
+    their __dict__ value, so the default unpickling after introduction of
+    slots attempts to set the __dict__ which fails with AttributeError.
+    Therefore, these methods need to be provided also for Python 3.
+
+    Also, because code in pywbem_mock/_resolvermixin.py dynamically added
+    the non-existing attributes 'classorigin' and 'propagated' to CIMClass
+    objects (that code has been removed meanwhile), the unpickling may
+    encounter CIMClass objects that still have these attributes set. That
+    is handled by ignoring these attributes during unpickling.
+
+    These methods support classes with both slotted and non-slotted attributes.
+    Support for non-slottted attributes is needed for example when users
+    define classes derived from CIM object or CIM type classes.
+    """
+
+    __slots__ = []
+
+    def __getstate__(self):
+        ""  # Avoids docstring to be inherited
+
+        dct = dict()
+        for attr in self.__slots__:
+            dct[attr] = getattr(self, attr)
+
+        # Support for objects that also have __dict__, e.g. user defined
+        # derived classes that did not define __slots__:
+        if hasattr(self, '__dict__'):
+            for attr in self.__dict__:
+                dct[attr] = getattr(self, attr)
+
+        return dct
+
+    def __setstate__(self, dct):
+        ""  # Avoids docstring to be inherited
+
+        # Defer import due to circular import dependencies:
+        # pylint: disable=import-outside-toplevel
+        from pywbem._cim_obj import CIMClass as class_type
+
+        for attr in dct:
+
+            # Compatibility support for CIMClass objects that were pickled
+            # before pywbem 1.2.0:
+            if isinstance(self, class_type) and \
+                    attr in ('classorigin', 'propagated'):
+                continue
+
+            setattr(self, attr, dct[attr])
+
+
+class MinutesFromUTC(SlottedPickleMixin, tzinfo):
     """
     Timezone information (an implementation of :class:`py:datetime.tzinfo`)
     that represents a fixed offset in +/- minutes from UTC and is thus suitable
@@ -204,6 +274,8 @@ class MinutesFromUTC(tzinfo):
                                                   pywbem.MinutesFromUTC(-300))
     """
 
+    __slots__ = ['_offset']
+
     def __init__(self, offset):  # pylint: disable=super-init-not-called
         """
         Parameters:
@@ -219,6 +291,9 @@ class MinutesFromUTC(tzinfo):
         self._offset = offset
 
     def __repr__(self):
+        """
+        Return a string representation suitable for debugging.
+        """
         return _format(
             "MinutesFromUTC("
             "offset={s._offset!A})",
@@ -275,9 +350,11 @@ class MinutesFromUTC(tzinfo):
         return "{sign}{hh:02d}:{mm:02d}".format(sign=sign, hh=hh, mm=mm)
 
 
-class CIMType(object):  # pylint: disable=too-few-public-methods
+class CIMType(SlottedPickleMixin):  # pylint: disable=too-few-public-methods
     """Base type for all CIM data types defined in this package."""
 
+    __slots__ = []
+
     #: The name of the CIM datatype, as a :term:`string`. See
     #: :ref:`CIM data types` for details.
     cimtype = None
@@ -297,11 +374,14 @@ class Char16(CIMType, six.text_type):
     KEYVALUE elements when creating the CIM-XML representation for a keybinding.
     """
 
+    __slots__ = []
+
     #: The name of the CIM datatype ``"char16"``
     cimtype = 'char16'
 
     # Changing the string content requires using __new__() instead of __init__()
     def __new__(cls, content=''):
+        ""  # Avoids docstring to be inherited
         return super(Char16, cls).__new__(cls, _ensure_unicode(content))
 
 
@@ -317,6 +397,8 @@ class CIMDateTime(_CIMComparisonMixin, CIMType):
     hash value being based on their public attributes.
     """
 
+    __slots__ = ['__timedelta', '__datetime', '__precision']
+
     #: The name of the CIM datatype ``"datetime"``
     cimtype = 'datetime'
 
@@ -706,12 +788,27 @@ class CIMDateTime(_CIMComparisonMixin, CIMType):
             s=self)
 
     def __getstate__(self):
+        ""  # Avoids docstring to be inherited
         return str(self)
 
     def __setstate__(self, arg):
+        ""  # Avoids docstring to be inherited
         self.__init__(arg)
 
     def __eq__(self, other):
+        """
+        Equality test function for two :class:`~pywbem.CIMDateTime` objects.
+
+        The equality is based on their public attributes.
+
+        Note that a :class:`~pywbem.CIMDateTime` object represents either a
+        time interval or a point in time but never both. Therefore, an object
+        representing an interval is never equal to an object representing a
+        point in time.
+
+        Returns `False` if the `other` object is not a
+        :class:`~pywbem.CIMDateTime` object.
+        """
         if self is other:
             return True
         if not isinstance(other, CIMDateTime):
@@ -782,6 +879,8 @@ class CIMInt(CIMType, _Longint):
         TypeError: int() can't convert non-string with explicit base
     """
 
+    __slots__ = []
+
     #: The minimum valid value for the integer, according to the capabilities
     #: of its CIM data type. See :ref:`CIM data types` for a list of CIM
     #: integer data types.
@@ -793,6 +892,7 @@ class CIMInt(CIMType, _Longint):
     maxvalue = None
 
     def __new__(cls, *args, **kwargs):
+        ""  # Avoids docstring to be inherited
 
         # Python 3.7 removed support for passing the value for int() as a
         # keyword argument named 'x'. It now needs to be passed as a positional
@@ -833,6 +933,9 @@ class Uint8(CIMInt):
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
     """
+
+    __slots__ = []
+
     #: The name of the CIM datatype
     cimtype = 'uint8'
     #: The minimum valid value for the CIM datatype
@@ -847,6 +950,9 @@ class Sint8(CIMInt):
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
     """
+
+    __slots__ = []
+
     #: The name of the CIM datatype
     cimtype = 'sint8'
     #: The minimum valid value for the CIM datatype
@@ -861,6 +967,9 @@ class Uint16(CIMInt):
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
     """
+
+    __slots__ = []
+
     #: The name of the CIM datatype
     cimtype = 'uint16'
     #: The minimum valid value for the CIM datatype
@@ -875,6 +984,9 @@ class Sint16(CIMInt):
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
     """
+
+    __slots__ = []
+
     #: The name of the CIM datatype
     cimtype = 'sint16'
     #: The minimum valid value for the CIM datatype
@@ -889,6 +1001,9 @@ class Uint32(CIMInt):
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
     """
+
+    __slots__ = []
+
     #: The name of the CIM datatype
     cimtype = 'uint32'
     #: The minimum valid value for the CIM datatype
@@ -903,6 +1018,9 @@ class Sint32(CIMInt):
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
     """
+
+    __slots__ = []
+
     #: The name of the CIM datatype
     cimtype = 'sint32'
     #: The minimum valid value for the CIM datatype
@@ -917,6 +1035,9 @@ class Uint64(CIMInt):
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
     """
+
+    __slots__ = []
+
     #: The name of the CIM datatype
     cimtype = 'uint64'
     #: The minimum valid value for the CIM datatype
@@ -931,6 +1052,9 @@ class Sint64(CIMInt):
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
     """
+
+    __slots__ = []
+
     #: The name of the CIM datatype
     cimtype = 'sint64'
     #: The minimum valid value for the CIM datatype
@@ -963,6 +1087,8 @@ class CIMFloat(CIMType, float):
     in sets.
     """
 
+    __slots__ = []
+
     # Note: __str__() is added later, for Python 3.
 
     def __repr__(self):
@@ -982,6 +1108,9 @@ class Real32(CIMFloat):
     class, or to use them as dictionary keys or as members in sets. See
     :class:`~pywbem.CIMFloat` for details.
     """
+
+    __slots__ = []
+
     #: The name of the CIM datatype
     cimtype = 'real32'
 
@@ -994,6 +1123,9 @@ class Real64(CIMFloat):
     class, or to use them as dictionary keys or as members in sets. See
     :class:`~pywbem.CIMFloat` for details.
     """
+
+    __slots__ = []
+
     #: The name of the CIM datatype
     cimtype = 'real64'
 
@@ -1065,30 +1197,24 @@ def cimtype(obj):
     if isinstance(obj, (datetime, timedelta)):
         return 'datetime'
 
-    try:
-        instancename_type = CIMInstanceName
-    except NameError:
-        # Defer import due to circular import dependencies:
-        # pylint: disable=import-outside-toplevel
-        from pywbem._cim_obj import CIMInstanceName as instancename_type
+    # Defer import due to circular import dependencies:
+    # pylint: disable=import-outside-toplevel
+    from pywbem._cim_obj import CIMInstanceName as instancename_type
+
     if isinstance(obj, instancename_type):
         return 'reference'
 
-    try:
-        instance_type = CIMInstance
-    except NameError:
-        # Defer import due to circular import dependencies:
-        # pylint: disable=import-outside-toplevel
-        from pywbem._cim_obj import CIMInstance as instance_type
+    # Defer import due to circular import dependencies:
+    # pylint: disable=import-outside-toplevel
+    from pywbem._cim_obj import CIMInstance as instance_type
+
     if isinstance(obj, instance_type):  # embedded instance
         return 'string'
 
-    try:
-        class_type = CIMClass
-    except NameError:
-        # Defer import due to circular import dependencies:
-        # pylint: disable=import-outside-toplevel
-        from pywbem._cim_obj import CIMClass as class_type
+    # Defer import due to circular import dependencies:
+    # pylint: disable=import-outside-toplevel
+    from pywbem._cim_obj import CIMClass as class_type
+
     if isinstance(obj, class_type):  # embedded class
         return 'string'
 
@@ -1143,6 +1269,10 @@ def type_from_name(type_name):
       Use `decode()` and `encode()` for strings instead of type conversion
       syntax (in both Python 2 and 3, for consistency).
 
+    * For CIM type "reference", type object :class:`~pywbem.CIMInstanceName`
+      is returned, even though for use in CIM method parameters,
+      :class:`~pywbem.CIMClassName` is also valid.
+
     Parameters:
 
       type_name (:term:`string`):
