@@ -140,7 +140,12 @@ class WBEMServer(object):
         'interop',
         'root/interop',
         'root/PG_Interop',
-        # TODO: Clarify which OpenPegasus versions need root/PGInterOp?
+        # OpenPegasus before version 2.12.0 defined only PG_Interop as the
+        # interop namespace. Using other namespaces was a manual
+        # modification of at least the pegasus/mak/configschema.mak file.
+        # Starting in version 2.12.0 a configuration variable was defined
+        # so that OpenPegasus could be build with any of the specified names
+        # for interop namespace (PEGASUS_INTEROP_NAMESPACE)
     ]
 
     #: A class variable with the possible names of CIM classes for
@@ -382,6 +387,11 @@ class WBEMServer(object):
         update this WBEMServer object to reflect the new namespace
         there.
 
+        This method cannot create an Interop namespace because creating the
+        an Interop namespace with client operations depends on the prior
+        existence of an Interop namespace, and creating additional Interop
+        namespaces if one already exists is usually prevented by servers.
+
         This method attempts the following approaches for creating the
         namespace, in order, until an approach succeeds:
 
@@ -423,7 +433,10 @@ class WBEMServer(object):
 
         std_namespace = _ensure_unicode(namespace.strip('/'))
 
-        ws_profiles = self.get_selected_profiles('DMTF', 'WBEM Server')
+        try:
+            ws_profiles = self.get_selected_profiles('DMTF', 'WBEM Server')
+        except (CIMError, ModelError):
+            ws_profiles = None
         if ws_profiles:
 
             # Use approach 1: Method defined in WBEM Server profile
@@ -520,6 +533,9 @@ class WBEMServer(object):
         The specified namespace must be empty (i.e. must not contain any
         classes, instances, or qualifier types.
 
+        This method cannot delete the Interop namespace because servers will
+        usually prevent their deletion.
+
         This method attempts the following approaches for deleting the
         namespace, in order, until an approach succeeds:
 
@@ -647,7 +663,7 @@ class WBEMServer(object):
             Exceptions raised by :class:`~pywbem.WBEMConnection`.
             CIMError: CIM_ERR_NOT_FOUND, Interop namespace could not be
               determined.
-            KeyError: If an instance in the list of profiles is incomplete
+            ModelError: If an instance in the list of profiles is incomplete
               and does not include the required properties.
         """
 
@@ -666,7 +682,7 @@ class WBEMServer(object):
             try:
                 inst_org_value = inst['RegisteredOrganization']
             except KeyError:
-                raise KeyError(
+                raise ModelError(
                     _format("CIM_RegisteredProfile instance in namespace "
                             "{0!A} does not have a property "
                             "'RegisteredOrganization'",
@@ -675,7 +691,7 @@ class WBEMServer(object):
             try:
                 inst_name = inst['RegisteredName']
             except KeyError:
-                raise KeyError(
+                raise ModelError(
                     _format("CIM_RegisteredProfile instance in namespace "
                             "{0!A} does not have a property "
                             "'RegisteredName'",
@@ -683,7 +699,7 @@ class WBEMServer(object):
             try:
                 inst_version = inst['RegisteredVersion']
             except KeyError:
-                raise KeyError(
+                raise ModelError(
                     _format("CIM_RegisteredProfile instance in namespace "
                             "{0!A} does not have a property "
                             "'RegisteredVersion'",
