@@ -31,7 +31,10 @@ import os
 import time
 import re
 from xml.dom import minidom
-from mock import Mock
+try:
+    from unittest.mock import Mock
+except ImportError:
+    from mock import Mock
 import six
 
 
@@ -117,7 +120,7 @@ class FakedWBEMConnection(WBEMConnection):
     with a WBEM server by utilizing a local in-memory CIM repository to
     generate responses in the same way the WBEM server would.
 
-    **Experimental:** *New in pywbem 0.12 as experimental.*
+    *New in pywbem 0.12 as experimental and finalized in 1.2.*
 
     Each :class:`~pywbem.FakedWBEMConnection` object has its own
     CIM repository which contains multiple CIM namespaces, and each namespace
@@ -183,6 +186,9 @@ class FakedWBEMConnection(WBEMConnection):
 
             The :attr:`~pywbem_mock.FakedWBEMConnection.disable_pull_operations`
             property can be used to set this variable.
+
+        Raises:
+          ValueError for invalid arguments
         """
 
         # Response delay in seconds. Any operation is delayed by this time.
@@ -212,18 +218,19 @@ class FakedWBEMConnection(WBEMConnection):
         self._provider_dependent_registry = ProviderDependentRegistry()
 
         # Define the datastore to be used with an initial namespace, the client
-        # connection default namespace. This is passed to the mainprovider
-        # and not used further in this class.
+        # connection default namespace. This is passed to the providerdispatcher
+        # and mainprovider and not used further in this class.
+        # Initiate instance of the ProviderDispatcher with required
+        # parameters including the CIM repository. This call initializes
+        # self.cimrepository.
+        self._providerdispatcher = ProviderDispatcher(
+            self.cimrepository, self._provider_registry)
 
         # Initiate the MainProvider with parameters required to execute
         self._mainprovider = MainProvider(self.host,
                                           self.disable_pull_operations,
-                                          self.cimrepository)
-
-        # Initiate instance of the ProviderDispatcher with required
-        # parameters including the CIM repository
-        self._providerdispatcher = ProviderDispatcher(
-            self._cimrepository, self._provider_registry)
+                                          self.cimrepository,
+                                          self._providerdispatcher)
 
         # Flag to allow or disallow the use of the Open... and Pull...
         # operations. Uses the setter method
@@ -520,10 +527,14 @@ class FakedWBEMConnection(WBEMConnection):
             Path name of the file containing the MOF definitions to be compiled.
 
           namespace (:term:`string`):
-            The name of the target CIM namespace in the CIM repository. This
-            namespace is also used for lookup of any existing or dependent
-            CIM objects. If `None`, the default namespace of the connection is
-            used.
+            The name of the CIM namespace in the associated CIM repository that
+            is the target of the compilation, and is also used for lookup of any
+            dependent CIM elements. If `None`, the default namespace of the
+            connection is used. A namespace defined in a namespace pragma of
+            the MOF superceeds this namespace from the point in the
+            compilation unit(string/file) where it is declared.  The namespace
+            specified in this parameter or the MOF inamespace pragma must
+            exist.
 
           search_paths (:term:`py:iterable` of :term:`string`):
             An iterable of directory path names where MOF dependent files will
@@ -541,6 +552,13 @@ class FakedWBEMConnection(WBEMConnection):
           :exc:`~pywbem.MOFCompileError`: Compile error in the MOF.
         """
 
+        # By default, error messages are always printed in addition to being
+        # raised as MOFCompileError. We only want them to be printed in verbose
+        # mode:
+        log_func_kwargs = dict()
+        if not verbose:
+            log_func_kwargs['log_func'] = None
+
         stats_name = "compile_mof_file(ns={!r})".format(namespace)
         with self.statistics(stats_name):
 
@@ -551,7 +569,7 @@ class FakedWBEMConnection(WBEMConnection):
             # WBEMConnection
             mofcomp = MOFCompiler(self._mofwbemconnection,
                                   search_paths=search_paths,
-                                  verbose=verbose, log_func=None)
+                                  verbose=verbose, **log_func_kwargs)
 
             mofcomp.compile_file(mof_file, namespace)
 
@@ -585,10 +603,14 @@ class FakedWBEMConnection(WBEMConnection):
             A string with the MOF definitions to be compiled.
 
           namespace (:term:`string`):
-            The name of the target CIM namespace in the CIM repository. This
-            namespace is also used for lookup of any existing or dependent
-            CIM objects. If `None`, the default namespace of the connection is
-            used.
+            The name of the CIM namespace in the associated CIM repository that
+            is the target of the compilation, and is also used for lookup of any
+            dependent CIM elements. If `None`, the default namespace of the
+            connection is used. A namespace defined in a namespace pragma of
+            the MOF superceeds this namespace from the point in the
+            compilation unit(string/file) where it is declared.  The namespace
+            specified in this parameter or the MOF inamespace pragma must
+            exist.
 
           search_paths (:term:`py:iterable` of :term:`string`):
             An iterable of directory path names where MOF dependent files will
@@ -606,6 +628,13 @@ class FakedWBEMConnection(WBEMConnection):
           :exc:`~pywbem.MOFCompileError`: Compile error in the MOF.
         """
 
+        # By default, error messages are always printed in addition to being
+        # raised as MOFCompileError. We only want them to be printed in verbose
+        # mode:
+        log_func_kwargs = dict()
+        if not verbose:
+            log_func_kwargs['log_func'] = None
+
         stats_name = "compile_mof_string(ns={!r})".format(namespace)
         with self.statistics(stats_name):
 
@@ -614,7 +643,7 @@ class FakedWBEMConnection(WBEMConnection):
 
             mofcomp = MOFCompiler(self._mofwbemconnection,
                                   search_paths=search_paths,
-                                  verbose=verbose, log_func=None)
+                                  verbose=verbose, **log_func_kwargs)
 
             mofcomp.compile_string(mof_str, namespace)
 
@@ -664,8 +693,14 @@ class FakedWBEMConnection(WBEMConnection):
             :attr:`pywbem_mock.DMTFCIMSchema.schema_pragma_file`.
 
           namespace (:term:`string`):
-            Namespace into which the classes and qualifier declarations will
-            be installed.
+            The name of the CIM namespace in the associated CIM repository that
+            is the target of the compilation, and is also used for lookup of any
+            dependent CIM elements. If `None`, the default namespace of the
+            connection is used. A namespace defined in a namespace pragma of
+            the MOF superceeds this namespace from the point in the
+            compilation unit(string/file) where it is declared.  The namespace
+            specified in this parameter or the MOF inamespace pragma must
+            exist.
 
           verbose (:class:`py:bool`):
             If `True`, progress messages are output to stdout as the schema is
@@ -905,7 +940,7 @@ class FakedWBEMConnection(WBEMConnection):
         'Methods').
         """
 
-        # Issue #2062: TODO/ks FUTURE Consider sorting to preserve order of
+        # Issue #2062: Consider sorting to preserve order of
         # compile/add. Make this part of refactor to separate repository and
         # datastore because it may be data store dependent
         _uprint(dest,
