@@ -6,24 +6,33 @@ from __future__ import absolute_import
 
 import os
 import warnings
+from contextlib import contextmanager
+import json
+import subprocess
+try:
+    from subprocess import DEVNULL
+except ImportError:
+    # Python 2.7
+    from subprocess import PIPE as DEVNULL
+import six
 import pytest
 import yaml
 
+# Note: The wbem_connection fixture uses the es_server fixture, and
+# due to the way py.test searches for fixtures, it also need to be imported.
+# pylint: disable=unused-import
+from pytest_easy_server import es_server  # noqa: F401
+# pylint: enable=unused-import
+
 from pywbem import WBEMServer, Error, ConnectionError, AuthError, \
     ToleratedServerIssueWarning  # pylint: disable=redefined-builtin
 
-from .server_definition_file import ServerDefinition, \
-    ServerDefinitionFile
 from .utils import latest_profile_inst, ServerObjectCache, \
     WBEMConnectionAsserted, server_func_asserted
 from .assertions import assert_association_a1, assert_association_a2, \
     assert_association_a3, assert_association_a4, assert_association_a5, \
     assert_association_a6
 
-# Server nickname or server group nickname in WBEM server definition file
-TESTSERVER = os.getenv('TESTSERVER', 'default')
-SD_LIST = ServerDefinitionFile().list_servers(TESTSERVER)
-
 # Profile definition file (in end2end directory).
 PROFILES_YAML_FILE = os.path.join('tests', 'profiles', 'profiles.yml')
 
@@ -31,107 +40,292 @@ PROFILES_YAML_FILE = os.path.join('tests', 'profiles', 'profiles.yml')
 # The list items are profile definition items, as described in the profile
 # definition file.
 with open(PROFILES_YAML_FILE, 'r') as _fp:
-    PROFILE_DEFINITION_LIST = yaml.load(_fp)
+    PROFILE_DEFINITION_LIST = yaml.safe_load(_fp)
 del _fp  # pylint: disable=undefined-loop-variable
 
 
-def fixtureid_server_definition(fixture_value):
+@contextmanager
+def server_from_docker(image_name, image_port, host_port, container_name,
+                       verbose=False):
     """
-    Return a fixture ID to be used by py.test, for fixture
-    `server_definition()`.
+    Context manager that creates a started WBEM server from a Docker image
+    of a WBEM server, if it does not already exist.
+
+    Upon entry, the context manager checks if a container with that name
+    exists. If so, it assumes it contains the server and starts the
+    container if not currently started. If a container with the name does not
+    exist, the image is pulled from DockerHub (using a local Docker cache)
+    and a container with that name is created and started.
+
+    Upon exit, the context manager leaves the container running.
+
+    For simplicity of code, the context manager can also be used when no Docker
+    image should be used by specifying image_name=None.
+
+    Note: This function requires the 'docker' command to be available locally.
 
     Parameters:
-      * fixture_value (ServerDefinition): The server definition of the
-        WBEM server the test runs against.
+
+      image_name (string):
+        Docker image name on DockerHub, e.g. org/name:1.2.3. If None, the
+        context manager does nothing and returns None.
+
+      image_port (int): Port number in image
+
+      host_port (int): Port number on host (local) system
+
+      container_name (string): Docker container name to use locally
+
+      verbose (bool): Print messages.
+
+    Returns:
+      URL of the running WBEM server, or None if image_name=None.
     """
-    sd = fixture_value
-    assert isinstance(sd, ServerDefinition)
-    return "server_definition={0}".format(sd.nickname)
+    if image_name:
+
+        # Find out whether container exists and is running
+        try:
+            inspect_out = subprocess.check_output(
+                ['docker', 'container', 'inspect', container_name],
+                stderr=DEVNULL)
+        except EnvironmentError as exc:
+            raise RuntimeError(
+                "Docker does not seem to be installed: {}".format(exc))
+        except subprocess.CalledProcessError as exc:
+            if exc.returncode > 1:
+                raise RuntimeError(
+                    "Command 'docker container inspect ...' failed: {}".
+                    format(exc))
+            container_exists = False
+            container_running = False
+        else:
+            container_exists = True
+            if isinstance(inspect_out, six.binary_type):
+                inspect_out = inspect_out.decode('utf-8')
+            _inspect_dict = json.loads(inspect_out)
+            _status = _inspect_dict[0]['State']['Status']
+            container_running = (_status == 'running')
+
+        if not container_exists:
+            docker_pull_with_cache(image_name, verbose=verbose)
+            if verbose:
+                print("Creating Docker container {} with "
+                      "image {}".format(container_name, image_name))
+            subprocess.check_call(
+                ['docker', 'create',
+                 '--name', container_name,
+                 '--publish', '{}:{}'.format(host_port, image_port),
+                 image_name],
+                stdout=DEVNULL)
+        else:
+            if verbose:
+                print("Using existing Docker container {}".
+                      format(container_name))
+
+        if not container_running:
+            if verbose:
+                print("Starting Docker container {}".format(container_name))
+            subprocess.check_call(
+                ['docker', 'start', container_name],
+                stdout=DEVNULL)
+        else:
+            if verbose:
+                print("Docker container {} was already running".
+                      format(container_name))
+
+        yield 'https://localhost:{}'.format(host_port)
+
+        # Leave the container running on exit.
+    else:
+        yield None
+
+
+def docker_pull_with_cache(image_name, verbose=False):
+    """
+    Pull a Docker image from DockerHub, using a Docker cache directory.
+
+    If the cache directory does not exist, it is created.
+
+    If the docker image does not exist in the cache directory, it is
+    pulled from DockerHub and saved as a TAR file in the cache directory.
+
+    If the docker image exists as a TAR file in the cache directory, it is
+    loaded from the TAR file.
+
+    In any case, the result is that the local Docker has the image available.
+
+    The path name of the cache directory is taken from the env var
+    DOCKER_CACHE_DIR and defaults to (see code) if not set.
+
+    Parameters:
+
+      image_name (string): Docker image name on DockerHub, e.g. org/name:1.2.3
+
+      verbose (bool): Print messages.
+    """
+    cache_dir = os.getenv('DOCKER_CACHE_DIR') or '~/docker-cache'
+    cache_dir = os.path.expanduser(cache_dir)
+
+    if not os.path.exists(cache_dir):
+        if verbose:
+            print("Creating local Docker image cache directory: {}".
+                  format(cache_dir))
+        os.makedirs(cache_dir, 0o755)
+
+    image_tar_fn = image_name.replace('/', '_').replace(':', '_') + '.tar'
+    image_tar_path = os.path.join(cache_dir, image_tar_fn)
+
+    if not os.path.exists(image_tar_path):
+
+        if verbose:
+            print("Pulling image from Docker Hub: {}".format(image_name))
+        subprocess.check_call(
+            ['docker', 'pull', image_name],
+            stdout=DEVNULL)
+
+        if verbose:
+            print("Saving image {} in local Docker image cache: {}".
+                  format(image_name, image_tar_path))
+        subprocess.check_call(
+            ['docker', 'save', '-o', image_tar_path, image_name],
+            stdout=DEVNULL)
+
+    else:
+
+        if verbose:
+            print("Loading image {} from local Docker image cache: {}".
+                  format(image_name, image_tar_path))
+        subprocess.check_call(
+            ['docker', 'load', '-i', image_tar_path],
+            stdout=DEVNULL)
+
+
+def skip_if_unsupported_capability(conn, cap_name):
+    """
+    Skip the pytest testcase if the specified capability is not supported
+    by the server at the connection.
+    """
+    if not supports_capability(conn, cap_name):
+        pytest.skip("Server {} does not support capability: {}".
+                    format(conn.es_server.nickname, cap_name))
+
+
+def supports_capability(conn, cap_name):
+    """
+    Return boolean indicating whether the specified capability is supported
+    by the server at the connection.
+    """
+    supported_caps = conn.es_server.user_defined.get('capabilities', [])
+    return cap_name in supported_caps
 
 
 @pytest.fixture(
-    params=SD_LIST,
-    scope='module',
-    ids=fixtureid_server_definition
+    scope='function'
 )
-def server_definition(request):
-    """
-    Fixture representing the set of WBEM server definitions to use for the
-    end2end tests.
-
-    Returns the `ServerDefinition` object of each server to test against.
-    """
-    return request.param
-
-
-@pytest.fixture(
-    scope='module'
-)
-def wbem_connection(request, server_definition):
+def wbem_connection(request, es_server):
     # pylint: disable=redefined-outer-name, unused-argument
     """
-    Fixture representing the set of WBEMConnection objects to use for the
-    end2end tests.  This fixture uses the
-    implementation_namespace item from the server_definition as the
-    default namespace if that item exists in the server_definition.
+    Fixture representing a WBEMConnection object to use for the end2end tests.
 
-    Returns the `WBEMConnection` object of each server to test against.
+    The fixture has function scope, so the connection is created for each
+    test function (including their parametrizations).
+
+    The WBEM server defined by the 'es_server' parameter is assumed to exist all
+    the time during the test session (= the pytest command). If the server
+    has a docker image definition, it is established and torn down
+    automatically, but only once during the test session.
+
+    Parameters:
+      es_server (easy_server.Server): Pytest fixture resolving to the server to
+        be tested against.
+
+    Returns:
+      pywbem.WBEMConnection: Connection to the server.
     """
-    sd = server_definition  # ServerDefinition object
 
-    # Skip this server if we had a skip reason in an earlier attempt
-    skip_msg = getattr(sd, 'skip_msg', None)
+    # Display messages about server that is used
+    verbose = False
+
+    # Skip this server if we had a skip reason in an earlier attempt.
+    # Note: We add an attribute to the es_server object to store this info.
+    skip_msg = getattr(es_server, 'skip_msg', None)
     if skip_msg:
         pytest.skip("Remembered skip reason from earlier attempt: {0}".
                     format(skip_msg))
 
-    x509 = dict(cert_file=sd.cert_file, key_file=sd.key_file) \
-        if sd.cert_file and sd.key_file else None
+    nickname = es_server.nickname
 
-    # Define the WBEMConnection default_namespace as the
-    # implementation_namespace if that data exists, else define it as
-    # None which invokes root/cimv2 as the default namespace.
-    # NOTE: Since WBEMConnection assigns root/cimv2 as default, there is
-    # no way to really know if a valid implementation namespace was defined.
-    conn = WBEMConnectionAsserted(
-        sd.url, (sd.user, sd.password),
-        x509=x509,
-        ca_certs=sd.ca_certs,
-        no_verification=sd.no_verification,
-        default_namespace=sd.implementation_namespace,
-        timeout=10,
-        server_definition=sd)
+    url = es_server.user_defined['url']
+    default_namespace = es_server.user_defined.get('default_namespace', None)
+    user = es_server.secrets['user']
+    password = es_server.secrets['password']
+    no_verification = es_server.secrets.get('no_verification', None)
+    ca_certs = es_server.secrets.get('ca_certs', None)
+    cert_file = es_server.secrets.get('cert_file', None)
+    key_file = es_server.secrets.get('key_file', None)
+    x509 = dict(cert_file=cert_file, key_file=key_file) \
+        if cert_file and key_file else None
 
-    # Check that the server can be reached and authenticated with, by issuing
-    # some quick operation. Operation failures are tolerated (e.g. GetQualifier
-    # is not supported on SFCB), and the connection and authgentication errors
-    # can still be detected because they will be detected before the operation
-    # fails.
-    try:
-        conn.GetQualifier(
-            'Association',
-            asserted=False)
-    except ConnectionError as exc:
-        msg = "Server {0} at {1}: Server cannot be reached: {2} - {3}". \
-            format(sd.nickname, sd.url, exc.__class__.__name__, exc)
-        sd.skip_msg = msg
-        warnings.warn(msg, ToleratedServerIssueWarning)
-        pytest.skip(msg)
-    except AuthError as exc:
-        msg = "Server {0} at {1}: Server cannot be authenticated with: " \
-            "{2} - {3}". \
-            format(sd.nickname, sd.url, exc.__class__.__name__, exc)
-        sd.skip_msg = msg
-        warnings.warn(msg, ToleratedServerIssueWarning)
-        pytest.skip(msg)
-    except Error:
-        # Any other error may be due to the WBEM server not supporting
-        # qualifier operations. In that case, we don't optimize.
-        sd.skip_msg = None
-    else:
-        sd.skip_msg = None
+    image_port = None
+    host_port = None
+    container_name = None
+    image_name = es_server.user_defined.get('docker_image', None)
+    if image_name:
+        port_mapping = es_server.user_defined.get('docker_port_mapping', None)
+        if port_mapping:
+            image_port = int(port_mapping['image'])
+            host_port = int(port_mapping['host'])
+        container_name = 'pywbem_end2endtest_{}'.format(nickname)
 
-    return conn
+    with server_from_docker(
+            image_name, image_port, host_port, container_name,
+            verbose=verbose):
+
+        if verbose:
+            print("Creating WBEM connection to: {}".format(url))
+
+        conn = WBEMConnectionAsserted(
+            url, (user, password), x509=x509,
+            ca_certs=ca_certs,
+            no_verification=no_verification,
+            default_namespace=default_namespace,
+            timeout=10,
+            es_server=es_server)
+
+        # Check that the server can be reached and authenticated with, by
+        # issuing some quick operation. Operation failures are tolerated
+        # (e.g. GetQualifier is not supported on SFCB), and the connection and
+        # authgentication errors can still be detected because they will be
+        # detected before the operation fails.
+        try:
+            conn.GetQualifier(
+                'Association',
+                asserted=False)
+        except ConnectionError as exc:
+            msg = "Server {0} at {1}: Server cannot be reached: {2} - {3}". \
+                format(nickname, url, exc.__class__.__name__, exc)
+            es_server.skip_msg = msg
+            warnings.warn(msg, ToleratedServerIssueWarning)
+            pytest.skip(msg)
+        except AuthError as exc:
+            msg = "Server {0} at {1}: Server cannot be authenticated with: " \
+                "{2} - {3}". \
+                format(nickname, url, exc.__class__.__name__, exc)
+            es_server.skip_msg = msg
+            warnings.warn(msg, ToleratedServerIssueWarning)
+            pytest.skip(msg)
+        except Error:
+            # Any other error may be due to the WBEM server not supporting
+            # qualifier operations. In that case, we don't optimize.
+            es_server.skip_msg = None
+        else:
+            es_server.skip_msg = None
+
+        yield conn
+
+        if verbose:
+            print("Closing WBEM connection to: {}".format(url))
+        conn.close()
 
 
 def fixtureid_default_namespace(fixture_value):
