@@ -134,6 +134,7 @@ import doctest
 import socket
 import re
 import traceback
+import warnings
 import threading
 from collections import namedtuple
 try:
@@ -152,7 +153,7 @@ import six
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
 from ..utils import import_installed
 pywbem = import_installed('pywbem')
-from pywbem._utils import _ensure_unicode  # noqa: E402
+from pywbem._utils import _ensure_unicode, _ensure_bytes  # noqa: E402
 from pywbem._nocasedict import NocaseDict  # noqa: E402
 # pylint: enable=wrong-import-position, wrong-import-order, invalid-name
 
@@ -204,7 +205,7 @@ def patched_makefile(self, mode='r', bufsize=-1):
         else:
             timeout = self.timeout
         t.join(timeout)
-        if t.isAlive():
+        if t.is_alive():
             raise socket.timeout
 
     return self.fd
@@ -420,7 +421,13 @@ def obj(value, tc_name):
                 if arg_name == "pywbem_object":
                     continue
                 ctor_args[arg_name] = obj(value[arg_name], tc_name)
-            obj_ = ctor_call(**ctor_args)
+            with pytest.warns(None) as rec_warnings:
+                obj_ = ctor_call(**ctor_args)
+            if rec_warnings:
+                for w in rec_warnings.list:
+                    # Ignore DeprecationWarnings, re-issue any others
+                    if w.category != DeprecationWarning:
+                        warnings.warn(w.message, w.category, 1)
         else:
             obj_ = OrderedDict()
             for key in value:
@@ -674,8 +681,12 @@ def assertXMLEqual(s_act, s_exp, entity):
 
     parser = etree.XMLParser(remove_blank_text=True)
     try:
-        x_act = etree.XML(s_act, parser=parser)
-        x_exp = etree.XML(s_exp, parser=parser)
+        # Note: lxml.etree.XML() has issues with unicode strings as input,
+        # so we pass UTF-8 encoded byte strings. See lxml bug
+        # https://bugs.launchpad.net/lxml/+bug/1902364 for a similar issue
+        # with lxml.etree.fromstring().
+        x_act = etree.XML(_ensure_bytes(s_act), parser=parser)
+        x_exp = etree.XML(_ensure_bytes(s_exp), parser=parser)
     except etree.XMLSyntaxError as exc:
         raise AssertionError("XML cannot be validated for %s: %s" %
                              (entity, exc))
