@@ -21,6 +21,9 @@ pywbem = import_installed('pywbem')
 from pywbem import WBEMConnection, ParseError, DEFAULT_NAMESPACE, \
     CIMError, CIMInstanceName, CIMClassName, CIMInstance, \
     CIMClass  # noqa: E402
+# pylint: disable=redefined-builtin
+from pywbem import ConnectionError  # noqa: E402
+# pylint: enable=redefined-builtin
 from pywbem._recorder import LogOperationRecorder  # noqa: E402
 from pywbem._recorder import TestClientRecorder as \
     MyTestClientRecorder  # noqa: E402
@@ -402,6 +405,84 @@ class TestCreateConnection(object):
         with pytest.raises(ValueError):
             conn.add_operation_recorder(LogOperationRecorder('fake_conn_id'))
 
+    def test_stats_enabled(self):  # pylint: disable=no-self-use
+        """
+        Test the property stats_enabled setter
+        """
+        conn = WBEMConnection('http://localhost')
+        assert conn.stats_enabled is False
+        conn.stats_enabled = True
+        assert conn.stats_enabled is True
+        conn.stats_enabled = False
+        assert conn.stats_enabled is False
+
+    def test_operation_recorder_enabled(self):  # pylint: disable=no-self-use
+        """
+        Test the property operation_recorder enabled setter
+        """
+        conn = WBEMConnection('http://localhost')
+        conn.add_operation_recorder(LogOperationRecorder('fake_conn_id'))
+        assert conn.operation_recorder_enabled is True
+        conn.operation_recorder_enabled = False
+        assert conn.operation_recorder_enabled is False
+        conn.operation_recorder_enabled = True
+        assert conn.operation_recorder_enabled is True
+
+    def test_close(self):  # pylint: disable=no-self-use
+        """
+        Test closing a connection once.
+        """
+        conn = WBEMConnection('http://localhost')
+        assert conn.session is not None
+        conn.close()
+        assert conn.session is None
+
+    def test_close_twice(self):  # pylint: disable=no-self-use
+        """
+        Test closing a connection twice.
+        """
+        conn = WBEMConnection('http://localhost')
+        conn.close()
+        assert conn.session is None
+        with pytest.raises(ConnectionError) as exc_info:
+            conn.close()
+            exc = exc_info.value
+            assert re.match(r'is closed', str(exc))
+
+    def test_close_imethod(self):  # pylint: disable=no-self-use
+        """
+        Test closing a connection and invoking an intrinsic operation.
+        """
+        conn = WBEMConnection('http://localhost')
+        conn.close()
+        assert conn.session is None
+        with pytest.raises(ConnectionError) as exc_info:
+            conn.GetClass('CIM_Foo')
+            exc = exc_info.value
+            assert re.match(r'is closed', str(exc))
+
+    def test_close_method(self):  # pylint: disable=no-self-use
+        """
+        Test closing a connection and invoking a CIM method.
+        """
+        conn = WBEMConnection('http://localhost')
+        conn.close()
+        assert conn.session is None
+        with pytest.raises(ConnectionError) as exc_info:
+            conn.InvokeMethod(ObjectName='CIM_Foo', MethodName='M1')
+            exc = exc_info.value
+            assert re.match(r'is closed', str(exc))
+
+    def test_context_manager(self):  # pylint: disable=no-self-use
+        """
+        Test the use of WBEMConnection as a context manager.
+        """
+        with WBEMConnection('http://localhost:5988') as conn:
+            assert isinstance(conn, WBEMConnection)
+            assert conn.url == 'http://localhost:5988'
+            assert conn.session is not None
+        assert conn.session is None
+
 
 class TestGetRsltParams(object):
     """Test WBEMConnection._get_rslt_params method."""
@@ -468,7 +549,7 @@ class TestGetRsltParams(object):
 
 def build_repo():
     """Fixture to initialize the mock environment and install classes.
-       Definde as a function without the pytest.fixture decorator becasue
+       Defined as a function without the pytest.fixture decorator because
        there is no way to include a fixture in the signature of a test
        function that uses simplified_test_function. Simplified_test_function
        reports a parameter count difference because of the extram parameter
@@ -653,12 +734,12 @@ TESTCASES_REQUEST_INVALID_PARAMS = [
         TypeError, None, OK
     ),
     (
-        "Test invalid invokemethod objectname None",
+        "Test invalid invokemethod inferred object integer None",
         dict(
             init_kwargs={},
             method='invokemethod',
             args=[None, "ObjectName"],
-            kwargs={},
+            kwargs={"param1": 1},
         ),
         TypeError, None, False  # Fails with connection failure.
     ),
@@ -705,6 +786,50 @@ TESTCASES_REQUEST_INVALID_PARAMS = [
         TypeError, None, OK
     ),
 
+    (
+        "Test OpenEnumerateInstances, Invalid type for operationtimeout",
+        dict(
+            init_kwargs={},
+            method='openenumerateinstances',
+            args=[CIMClass("CIMBlah")],
+            kwargs={"OperationTimeout": "shouldbeinteger"},
+        ),
+        TypeError, None, OK
+    ),
+
+    (
+        "Test OpenEnumerateInstances, Invalid value for operationtimeout",
+        dict(
+            init_kwargs={},
+            method='openenumerateinstances',
+            args=[CIMClass("CIMBlah")],
+            kwargs={"OperationTimeout": -30},
+        ),
+        TypeError, None, OK
+    ),
+
+    (
+        "Test OpenEnumerateInstancepaths, Invalid type for operationtimeout",
+        dict(
+            init_kwargs={},
+            method='openenumerateinstancepaths',
+            args=[CIMClass("CIMBlah")],
+            kwargs={"OperationTimeout": "shouldbeinteger"},
+        ),
+        TypeError, None, OK
+    ),
+
+    (
+        "Test OpenEnumerateInstancePaths, Invalid value for operationtimeout",
+        dict(
+            init_kwargs={},
+            method='openenumerateinstancepaths',
+            args=[CIMClass("CIMBlah")],
+            kwargs={"OperationTimeout": -30},
+        ),
+        TypeError, None, OK
+    ),
+
     (
         "Test pullinstancewithpath, Invalid context type",
         dict(
@@ -867,6 +992,9 @@ def test_request_invalid_params(testcase, init_kwargs, method, args, kwargs):
     elif method == 'openenumerateinstances':
         _ = conn.OpenEnumerateInstances(*args, **kwargs)
 
+    elif method == 'openenumerateinstancepaths':
+        _ = conn.OpenEnumerateInstancePaths(*args, **kwargs)
+
     elif method == 'pullinstanceswithpath':
         _ = conn.PullInstancesWithPath(*args, **kwargs)
 
@@ -883,3 +1011,23 @@ def test_request_invalid_params(testcase, init_kwargs, method, args, kwargs):
     # Ensure that exceptions raised in the remainder of this function
     # are not mistaken as expected exceptions
     assert testcase.exp_exc_types is None
+
+
+def test_close():
+    """
+    Test WBEMConnection.close().
+    """
+
+    conn = WBEMConnection('http://localhost')
+
+    assert conn.session is not None
+
+    # The code to be tested, good case
+    conn.close()
+
+    assert conn.session is None
+
+    with pytest.raises(ConnectionError):
+
+        # The code to be tested, error case
+        conn.close()
