@@ -11,13 +11,13 @@ import errno
 import re
 import logging
 from time import time, sleep
-import datetime
 from random import randint
 import requests
 import pytest
 
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
-from ...utils import import_installed
+from ...utils import import_installed, post_bsl
+from ...elapsed_timer import ElapsedTimer
 from ..utils.pytest_extensions import simplified_test_function
 pywbem = import_installed('pywbem')
 from pywbem import WBEMListener  # noqa: E402
@@ -55,36 +55,6 @@ if LOGLEVEL > logging.NOTSET:
     configure_root_logger(LOGFILE)
 
 
-class ElapsedTimer(object):
-    """
-    Elapsed time timer.
-
-    Calculates elapsed time between initiation/reset and access.
-    """
-
-    def __init__(self):
-        """ Initiate the object with current time"""
-        self.start_time = datetime.datetime.now()
-
-    def reset(self):
-        """ Reset the start time for the timer"""
-        self.start_time = datetime.datetime.now()
-
-    def elapsed_ms(self):
-        """ Get the elapsed time in milliseconds. returns floating
-            point representation of elapsed time in seconds.
-        """
-        dt = datetime.datetime.now() - self.start_time
-        return ((dt.days * 24 * 3600) + dt.seconds) * 1000 + \
-            dt.microseconds / 1000.0
-
-    def elapsed_sec(self):
-        """ get the elapsed time in seconds. Returns floating
-            point representation of time in seconds
-        """
-        return self.elapsed_ms() / 1000
-
-
 TESTCASES_WBEMLISTENER_INIT = [
 
     # Testcases for WBEMListener.__init__()
@@ -710,8 +680,7 @@ def test_WBEMListener_send_indications(send_count):
             LOGGER.debug("Testcase sending indication #%s", i)
 
             try:
-                response = requests.post(url, headers=headers, data=payload,
-                                         timeout=4)
+                response = post_bsl(url, headers=headers, data=payload)
             except requests.exceptions.RequestException as exc:
                 msg = ("Testcase sending indication #{} raised {}: {}".
                        format(i, exc.__class__.__name__, exc))
@@ -921,7 +890,7 @@ def test_WBEMListener_incorrect_headers(desc, headers, exp_status, exp_headers):
     try:
 
         # The code to be tested is running in listener thread
-        response = requests.post(url, headers=headers, timeout=4)
+        response = post_bsl(url, headers=headers, data=None)
 
         assert response.status_code == exp_status
         for header_name in exp_headers:
@@ -958,7 +927,7 @@ WBEMLISTENER_INCORRECT_PAYLOAD1_TESTCASES = [
         </CIM>""",
         400,
         {
-            'CIMErrorDetails': r'DTD version 1.4 not supported.*',
+            'CIMErrorDetails': r'DTDVERSION is 1.4, expected 2.x.y',
             'CIMError': r'unsupported-dtd-version',
             'CIMExport': r'MethodResponse',
         }
@@ -976,7 +945,7 @@ WBEMLISTENER_INCORRECT_PAYLOAD1_TESTCASES = [
         </CIM>""",
         400,
         {
-            'CIMErrorDetails': r'Protocol version 2.4 not supported.*',
+            'CIMErrorDetails': r'PROTOCOLVERSION is 2.4, expected 1.x.y',
             'CIMError': r'unsupported-protocol-version',
             'CIMExport': r'MethodResponse',
         }
@@ -988,7 +957,7 @@ WBEMLISTENER_INCORRECT_PAYLOAD1_TESTCASES = [
         </CIM>""",
         400,
         {
-            'CIMErrorDetails': r'Element .CIM. missing required '
+            'CIMErrorDetails': r'Element .CIM. is missing required '
                                r'child element .*.MESSAGE..*',
             'CIMError': r'request-not-well-formed',
             'CIMExport': r'MethodResponse',
@@ -1003,7 +972,7 @@ WBEMLISTENER_INCORRECT_PAYLOAD1_TESTCASES = [
         </CIM>""",
         400,
         {
-            'CIMErrorDetails': r'Element .MESSAGE. missing required '
+            'CIMErrorDetails': r'Element .MESSAGE. is missing required '
                                r'child element .*.SIMPLEEXPREQ..*',
             'CIMError': r'request-not-well-formed',
             'CIMExport': r'MethodResponse',
@@ -1020,7 +989,7 @@ WBEMLISTENER_INCORRECT_PAYLOAD1_TESTCASES = [
         </CIM>""",
         400,
         {
-            'CIMErrorDetails': r'Element .SIMPLEEXPREQ. missing required '
+            'CIMErrorDetails': r'Element .SIMPLEEXPREQ. is missing required '
                                r'child element .*.EXPMETHODCALL..*',
             'CIMError': r'request-not-well-formed',
             'CIMExport': r'MethodResponse',
@@ -1081,7 +1050,7 @@ def test_WBEMListener_incorrect_payload1(
     try:
 
         # The code to be tested is running in listener thread
-        response = requests.post(url, headers=headers, data=payload, timeout=4)
+        response = post_bsl(url, headers=headers, data=payload)
 
         assert response.status_code == exp_status
         for header_name in exp_headers:
@@ -1246,7 +1215,7 @@ def test_WBEMListener_incorrect_payload2(
     try:
 
         # The code to be tested is running in listener thread
-        response = requests.post(url, headers=headers, data=payload, timeout=4)
+        response = post_bsl(url, headers=headers, data=payload)
 
         assert response.status_code == exp_status
         for header_name in exp_headers:
